@@ -152,7 +152,7 @@ ToDiagrammeRGraph <- function(root, direction = c("climb", "descend"), pruneFun
   nodeAttributes <- NULL
   edgeAttributes <- NULL
   
-  graph <- set_global_graph_attrs(graph, "layout", "dot", "graph")
+  #graph <- set_global_graph_attrs(graph, "layout", "dot", "graph")
   
   graph <- add_global_graph_attrs(graph, 
                                   c(names(graphAttributes), names(nodeAttributes), names(edgeAttributes)), 
